@@ -14,7 +14,7 @@ use Scalar::Util;
 
 with 'Data::Object::Role::Hash';
 
-our $VERSION = '0.56'; # VERSION
+our $VERSION = '0.57'; # VERSION
 
 method new ($class: @args) {
 
@@ -66,7 +66,7 @@ Data::Object::Hash - Hash Object for Perl 5
 
 =head1 VERSION
 
-version 0.56
+version 0.57
 
 =head1 SYNOPSIS
 
@@ -96,15 +96,7 @@ supply a callback to the method called. A codified string can access its
 arguments by using variable names which correspond to letters in the alphabet
 which represent the position in the argument list. For example:
 
-    $array->example('($index, $value)');
-
-    # or
-
-    $array->example_batch('($index0, $value0)');
-
-    # or
-
-    $array->example('$a + $b * $c', 100);
+    $hash->example('$a + $b * $c', 100);
 
     # if the example method does not supply any arguments automatically then
     # the variable $a would be assigned the user-supplied value of 100,
@@ -112,57 +104,19 @@ which represent the position in the argument list. For example:
     # those arugments would be assigned to the variables $a and $b whereas $c
     # would be assigned the user-supplied value of 100
 
+    # e.g.
+
+    $hash->each('the value at $key is $value');
+
+    # or
+
+    $hash->each_n_values(4, 'the value at $key0 is $value0');
+
+    # etc
+
 Any place a codified string is accepted, a coderef or L<Data::Object::Code>
 object is also valid. Arguments are passed through the usual C<@_> list.
 
-=head1 ROLES
-
-This package is comprised of the following roles.
-
-=over 4
-
-=item *
-
-L<Data::Object::Role::Collection>
-
-=item *
-
-L<Data::Object::Role::Comparison>
-
-=item *
-
-L<Data::Object::Role::Defined>
-
-=item *
-
-L<Data::Object::Role::Detract>
-
-=item *
-
-L<Data::Object::Role::Dumper>
-
-=item *
-
-L<Data::Object::Role::Item>
-
-=item *
-
-L<Data::Object::Role::List>
-
-=item *
-
-L<Data::Object::Role::Output>
-
-=item *
-
-L<Data::Object::Role::Throwable>
-
-=item *
-
-L<Data::Object::Role::Type>
-
-=back
-
 =head1 METHODS
 
 =head2 clear
@@ -698,6 +652,54 @@ L<Data::Object::Hash> object.
 The values method returns an array reference consisting of the values of the
 elements in the hash. This method returns a L<Data::Object::Array> object.
 
+=head1 ROLES
+
+This package is comprised of the following roles.
+
+=over 4
+
+=item *
+
+L<Data::Object::Role::Collection>
+
+=item *
+
+L<Data::Object::Role::Comparison>
+
+=item *
+
+L<Data::Object::Role::Defined>
+
+=item *
+
+L<Data::Object::Role::Detract>
+
+=item *
+
+L<Data::Object::Role::Dumper>
+
+=item *
+
+L<Data::Object::Role::Item>
+
+=item *
+
+L<Data::Object::Role::List>
+
+=item *
+
+L<Data::Object::Role::Output>
+
+=item *
+
+L<Data::Object::Role::Throwable>
+
+=item *
+
+L<Data::Object::Role::Type>
+
+=back
+
 =head1 SEE ALSO
 
 =over 4
