@@ -17,7 +17,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Item
 );
 
-our $VERSION = '0.56'; # VERSION
+our $VERSION = '0.57'; # VERSION
 
 method clear () {
 
@@ -548,7 +548,7 @@ Data::Object::Role::Hash - Hash Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.56
+version 0.57
 
 =head1 SYNOPSIS
 
@@ -567,14 +567,6 @@ supply a callback to the method called. A codified string can access its
 arguments by using variable names which correspond to letters in the alphabet
 which represent the position in the argument list. For example:
 
-    $hash->example('($key, $value)');
-
-    # or
-
-    $hash->example_batch('($key0, $value0)');
-
-    # or
-
     $hash->example('$a + $b * $c', 100);
 
     # if the example method does not supply any arguments automatically then
@@ -583,57 +575,19 @@ which represent the position in the argument list. For example:
     # those arugments would be assigned to the variables $a and $b whereas $c
     # would be assigned the user-supplied value of 100
 
+    # e.g.
+
+    $hash->each('the value at $key is $value');
+
+    # or
+
+    $hash->each_n_values(4, 'the value at $key0 is $value0');
+
+    # etc
+
 Any place a codified string is accepted, a coderef or L<Data::Object::Code>
 object is also valid. Arguments are passed through the usual C<@_> list.
 
-=head1 ROLES
-
-This package is comprised of the following roles.
-
-=over 4
-
-=item *
-
-L<Data::Object::Role::Collection>
-
-=item *
-
-L<Data::Object::Role::Comparison>
-
-=item *
-
-L<Data::Object::Role::Defined>
-
-=item *
-
-L<Data::Object::Role::Detract>
-
-=item *
-
-L<Data::Object::Role::Dumper>
-
-=item *
-
-L<Data::Object::Role::Item>
-
-=item *
-
-L<Data::Object::Role::List>
-
-=item *
-
-L<Data::Object::Role::Output>
-
-=item *
-
-L<Data::Object::Role::Throwable>
-
-=item *
-
-L<Data::Object::Role::Type>
-
-=back
-
 =head1 METHODS
 
 =head2 clear
@@ -1169,6 +1123,54 @@ hash object.
 The values method returns an array reference consisting of the values of the
 elements in the hash. This method returns an array value.
 
+=head1 ROLES
+
+This package is comprised of the following roles.
+
+=over 4
+
+=item *
+
+L<Data::Object::Role::Collection>
+
+=item *
+
+L<Data::Object::Role::Comparison>
+
+=item *
+
+L<Data::Object::Role::Defined>
+
+=item *
+
+L<Data::Object::Role::Detract>
+
+=item *
+
+L<Data::Object::Role::Dumper>
+
+=item *
+
+L<Data::Object::Role::Item>
+
+=item *
+
+L<Data::Object::Role::List>
+
+=item *
+
+L<Data::Object::Role::Output>
+
+=item *
+
+L<Data::Object::Role::Throwable>
+
+=item *
+
+L<Data::Object::Role::Type>
+
+=back
+
 =head1 SEE ALSO
 
 =over 4
